@@ -1,10 +1,13 @@
 package Data::Format::Pretty::Console;
 
+our $DATE = '2015-08-17'; # DATE
+our $VERSION = '0.34'; # VERSION
+
 use 5.010001;
 use strict;
 use warnings;
 use experimental 'smartmatch';
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 
 use Data::Unixish::Apply;
 use Scalar::Util qw(blessed);
@@ -18,8 +21,6 @@ require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(format_pretty);
 
-our $VERSION = '0.33'; # VERSION
-
 sub content_type { "text/plain" }
 
 sub format_pretty {
@@ -485,7 +486,7 @@ Data::Format::Pretty::Console - Pretty-print data structure for console output
 
 =head1 VERSION
 
-version 0.33
+This document describes version 0.34 of Data::Format::Pretty::Console (from Perl distribution Data-Format-Pretty-Console), released on 2015-08-17.
 
 =head1 SYNOPSIS
 
@@ -603,8 +604,6 @@ program.
 Most of the time, you don't have to configure anything, but some options are
 provided to tweak the output.
 
-This module uses L<Log::Any> for logging.
-
 =for Pod::Coverage ^(content_type)$
 
 =head1 FUNCTIONS
@@ -697,18 +696,6 @@ To override terminal width detection.
 
 =back
 
-=head1 TODO
-
-=over
-
-=item * when displaying list in columns, option to fill column-wise instead of row-wise
-
-This is like 'ls -x' (our default) vs 'ls'.
-
-Probably set via C<list_fill_by_columns> option.
-
-=back
-
 =head1 SEE ALSO
 
 Modules used for formatting: L<Text::ANSITable>, L<YAML>.
@@ -733,11 +720,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
